@@ -1,25 +1,13 @@
-/***************************************************************************
- *   Copyright 2011 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2011 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef PALAPELI_PUZZLE_H
 #define PALAPELI_PUZZLE_H
 
-#include <QFuture>
+#include <QObject>
 #include <QMetaType>
 
 #include <iostream>
@@ -65,16 +53,13 @@ namespace Palapeli
 			Palapeli::Puzzle* m_puzzle;
 	};
 
-	typedef QFuture<const Palapeli::PuzzleComponent*> Future;
-	typedef QFutureWatcher<const Palapeli::PuzzleComponent*> FutureWatcher;
-
 	class Puzzle : public QObject
 	{
 		Q_OBJECT
 		public:
 			///Takes ownership of @a mainComponent.
 			Puzzle(Palapeli::PuzzleComponent* mainComponent, const QString& location, const QString& identifier);
-			virtual ~Puzzle();
+			~Puzzle() override;
 
 			///Returns an identifier for use with puzzles loaded from the file
 			///system. Rationale: The identifier must be unique during the
@@ -93,19 +78,11 @@ namespace Palapeli
 				return dynamic_cast<const T*>(component((Palapeli::PuzzleComponent::Type) T::ComponentType));
 			}
 			///Requests that the given component @a type is made available.
-			///Use the returned future to get the component once the operation
-			///has finished. The future's waitForFinished() method can be used
-			///for synchronized access.
-			Palapeli::Future get(Palapeli::PuzzleComponent::Type type);
+			const Palapeli::PuzzleComponent *get(Palapeli::PuzzleComponent::Type type);
 
 			QString identifier() const;
 			QString location() const;
 			void setLocation(const QString& location);
-			///Resets the main component, which is used for casting. Components
-			///which were created before the setMainComponent() call are not
-			///affected. Other components of the same type will be overwritten
-			///by the given @a component.
-			void setMainComponent(Palapeli::PuzzleComponent* component);
 
 			///Deletes the component with the given @a type from this puzzle.
 			///Because the component might be in use elsewhere in the program,
